##  Impacts Execution Order
The implied and custom impacts are executed in a particular order. This ensures a logical sequence of changes on the affected Fact Sheets.
Impacts are grouped and executed in the following order:
  1. Set field to
  2. Set lifecycle phase
  3. Copy field to
  4. Replace tags
  5. Add tags
  6. Remove tags
  7. Remove relations
  8. Remove all relations
  9. Create relations
  10. Copy all relations from
  11. Move all relations from
  12. Set relation field to
  13. Set relation validity
  14. Remove relation constraints
  15. Create relation constraints


When a Transformation is defined in the Initiative Fact Sheet, impacts are grouped and displayed in the same order as mentioned above, regardless of when a new impact was added.
![Custom Impacts in an Intiative Fact Sheet Grouped and Ordered Based on Execution Order.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2751b1e37a441014a7ccf640ec9d947d_LowRes.png)
Custom Impacts in an Intiative Fact Sheet Grouped and Ordered Based on Execution Order.
